-- Tipex by Andromerius (asilva) v1.7

Tipex = LibStub("AceAddon-3.0"):NewAddon("Tipex", "AceConsole-3.0", "AceEvent-3.0")

local globalDB
local options = {
    name = "Tipex",
    handler = Tipex,
    type = "group",
    args = {
        showInCombat = {
			order = 1,
            type = "toggle",
            name = "Show in combat",
            desc = "Activates the display of tooltips in combat.",
            get = "IsShowInCombat",
            set = "ToggleShowInCombat",
        },
		disableOnMouse = {
		order = 2,
		type = "toggle",
		name = "Disable tooltips on mouse",
		desc = "Resets tooltip showing to default.",
		get = "IsDisabledOnMouse",
		set = "ToggleOnMouse",
		},
    },
}

local defaults = {
    profile = {
        showInCombat = false,
		disableTooltips = false,
    },
}

-- Initialize addon --
function Tipex:OnInitialize()

    -- Called when the addon is loaded
    self.db = LibStub("AceDB-3.0"):New("TipexDB", defaults, true)
	globalDB = self.db.global

    LibStub("AceConfig-3.0"):RegisterOptionsTable("Tipex", options)
    self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("Tipex", "Tipex")
    self:RegisterChatCommand("tipex", "ChatCommand")
    self:RegisterChatCommand("Tipex", "ChatCommand")

end

-- Initialize combat checks and set Addon status
local addon = CreateFrame("Frame")

--register events
addon:RegisterEvent("PLAYER_ENTERING_WORLD")
addon:RegisterEvent("PLAYER_REGEN_DISABLED")
addon:RegisterEvent("PLAYER_REGEN_ENABLED")
addon:RegisterEvent("UPDATE_MOUSEOVER_UNIT");
addon:RegisterEvent("ADDON_LOADED");

-- call function based on events
addon:SetScript("OnEvent", function(self, event, ...)

if (event == "UPDATE_MOUSEOVER_UNIT") then
	local _, unit = GameTooltip:GetUnit()
	
	if UnitAffectingCombat("player") and (Tipex:IsShowInCombat()) then
					function GameTooltip_SetDefaultAnchor(tooltip, parent)
					tooltip:ClearAllPoints()
					tooltip:SetOwner(UIParent, "ANCHOR_CURSOR")
					end

	elseif UnitAffectingCombat("player") and not (Tipex:IsShowInCombat()) then
					function GameTooltip_SetDefaultAnchor(tooltip, parent)
					tooltip:ClearAllPoints()
					tooltip:Hide();
					end

	elseif not UnitAffectingCombat("player") and (Tipex:IsDisabledOnMouse()) then
					function GameTooltip_SetDefaultAnchor(tooltip, parent)
					tooltip:ClearAllPoints()
					tooltip:SetOwner(UIParent, "ANCHOR_NONE")
					end

	elseif not UnitAffectingCombat("player") and not (Tipex:IsDisabledOnMouse()) then
					function GameTooltip_SetDefaultAnchor(tooltip, parent)
					tooltip:ClearAllPoints()
					tooltip:SetOwner(UIParent, "ANCHOR_CURSOR")
					end
	end

end
end)

-- Command line options.
function Tipex:ChatCommand(input)
    if not input or input:trim() == "" then
        InterfaceOptionsFrame_OpenToCategory(self.optionsFrame)
    else
        LibStub("AceConfigCmd-3.0"):HandleCommand("tipex", "Tipex", input)
    end
end

-- options db functions.
function Tipex:IsShowInCombat(info)
    return self.db.profile.showInCombat
end

function Tipex:ToggleShowInCombat(info, value)
    self.db.profile.showInCombat = value
end

function Tipex:IsDisabledOnMouse(info)
    return self.db.profile.disableOnMouse
end

function Tipex:ToggleOnMouse(info, value)
    self.db.profile.disableOnMouse = value
end
